Module blaxel.openai.tools
==========================

Functions
---------

`bl_tools(tools_names: list[str], **kwargs) ‑> list[agents.tool.FunctionTool]`
:   

`get_openai_tool(tool: blaxel.core.tools.types.Tool) ‑> agents.tool.FunctionTool`
: